/***************************************************************************
* File Name: DataInDMA_dma.c  
* Version 1.70
*
*  Description:
*   Provides an API for the DMAC component. The API includes functions
*   for the DMA controller, DMA channels and Transfer Descriptors.
*
*
*   Note:
*     This module requires the developer to finish or fill in the auto
*     generated funcions and setup the dma channel and TD's.
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
#include <CYLIB.H>
#include <CYDMAC.H>
#include <DataInDMA_dma.H>



/****************************************************************************
* 
* The following defines are available in Cyfitter.h
* 
* 
* 
* DataInDMA__DRQ_CTL_REG
* 
* 
* DataInDMA__DRQ_NUMBER
* 
* Number of TD's used by this channel.
* DataInDMA__NUMBEROF_TDS
* 
* Priority of this channel.
* DataInDMA__PRIORITY
* 
* True if DataInDMA_TERMIN_SEL is used.
* DataInDMA__TERMIN_EN
* 
* TERMIN interrupt line to signal terminate.
* DataInDMA__TERMIN_SEL
* 
* 
* True if DataInDMA_TERMOUT0_SEL is used.
* DataInDMA__TERMOUT0_EN
* 
* 
* TERMOUT0 interrupt line to signal completion.
* DataInDMA__TERMOUT0_SEL
* 
* 
* True if DataInDMA_TERMOUT1_SEL is used.
* DataInDMA__TERMOUT1_EN
* 
* 
* TERMOUT1 interrupt line to signal completion.
* DataInDMA__TERMOUT1_SEL
* 
****************************************************************************/


/* Zero based index of DataInDMA dma channel */
uint8 DataInDMA_DmaHandle = DMA_INVALID_CHANNEL;

/*********************************************************************
* Function Name: uint8 DataInDMA_DmaInitalize
**********************************************************************
* Summary:
*   Allocates and initialises a channel of the DMAC to be used by the
*   caller.
*
* Parameters:
*   BurstCount.
*       
*       
*   ReqestPerBurst.
*       
*       
*   UpperSrcAddress.
*       
*       
*   UpperDestAddress.
*       
*
* Return:
*   The channel that can be used by the caller for DMA activity.
*   DMA_INVALID_CHANNEL (0xFF) if there are no channels left. 
*
*
*******************************************************************/
uint8 DataInDMA_DmaInitialize(uint8 BurstCount, uint8 ReqestPerBurst, uint16 UpperSrcAddress, uint16 UpperDestAddress) 
{

    /* Allocate a DMA channel. */
    DataInDMA_DmaHandle = (uint8)DataInDMA__DRQ_NUMBER;

    /* Configure the channel. */
    (void)CyDmaChSetConfiguration(DataInDMA_DmaHandle,
                                  BurstCount,
                                  ReqestPerBurst,
                                  (uint8)DataInDMA__TERMOUT0_SEL,
                                  (uint8)DataInDMA__TERMOUT1_SEL,
                                  (uint8)DataInDMA__TERMIN_SEL);

    /* Set the extended address for the transfers */
    (void)CyDmaChSetExtendedAddress(DataInDMA_DmaHandle, UpperSrcAddress, UpperDestAddress);

    /* Set the priority for this channel */
    (void)CyDmaChPriority(DataInDMA_DmaHandle, (uint8)DataInDMA__PRIORITY);
    
    return DataInDMA_DmaHandle;
}

/*********************************************************************
* Function Name: void DataInDMA_DmaRelease
**********************************************************************
* Summary:
*   Frees the channel associated with DataInDMA.
*
*
* Parameters:
*   void.
*
*
*
* Return:
*   void.
*
*******************************************************************/
void DataInDMA_DmaRelease(void) 
{
    /* Disable the channel */
    (void)CyDmaChDisable(DataInDMA_DmaHandle);
}

